==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/CreateScheduledAuditResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.ScheduledAuditArn
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateScheduledAuditResponse(
    scheduledAuditArn: Optional[ScheduledAuditArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.CreateScheduledAuditResponse = {
    import CreateScheduledAuditResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.CreateScheduledAuditResponse
      .builder()
      .optionallyWith(
        scheduledAuditArn.map(value =>
          ScheduledAuditArn.unwrap(value): java.lang.String
        )
      )(_.scheduledAuditArn)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.CreateScheduledAuditResponse.ReadOnly =
    zio.aws.iot.model.CreateScheduledAuditResponse.wrap(buildAwsValue())
}
object CreateScheduledAuditResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.CreateScheduledAuditResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.CreateScheduledAuditResponse =
      zio.aws.iot.model
        .CreateScheduledAuditResponse(scheduledAuditArn.map(value => value))
    def scheduledAuditArn: Optional[ScheduledAuditArn]
    def getScheduledAuditArn: ZIO[Any, AwsError, ScheduledAuditArn] =
      AwsError.unwrapOptionField("scheduledAuditArn", scheduledAuditArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.CreateScheduledAuditResponse
  ) extends zio.aws.iot.model.CreateScheduledAuditResponse.ReadOnly {
    override val scheduledAuditArn: Optional[ScheduledAuditArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scheduledAuditArn())
        .map(value => zio.aws.iot.model.primitives.ScheduledAuditArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.CreateScheduledAuditResponse
  ): zio.aws.iot.model.CreateScheduledAuditResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iot_3-5.17.148.1-sources.jar: zio/aws/iot/model/CreateScheduledAuditResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.ScheduledAuditArn
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateScheduledAuditResponse(
    scheduledAuditArn: Option[ScheduledAuditArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.CreateScheduledAuditResponse = {
    import CreateScheduledAuditResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.CreateScheduledAuditResponse
      .builder()
      .optionallyWith(
        scheduledAuditArn.map(value =>
          ScheduledAuditArn.unwrap(value): java.lang.String
        )
      )(_.scheduledAuditArn)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.CreateScheduledAuditResponse.ReadOnly =
    zio.aws.iot.model.CreateScheduledAuditResponse.wrap(buildAwsValue())
}
object CreateScheduledAuditResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.CreateScheduledAuditResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.CreateScheduledAuditResponse =
      zio.aws.iot.model
        .CreateScheduledAuditResponse(scheduledAuditArn.map(value => value))
    def scheduledAuditArn: Option[ScheduledAuditArn]
    def getScheduledAuditArn: ZIO[Any, AwsError, ScheduledAuditArn] =
      AwsError.unwrapOptionField("scheduledAuditArn", scheduledAuditArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.CreateScheduledAuditResponse
  ) extends zio.aws.iot.model.CreateScheduledAuditResponse.ReadOnly {
    override val scheduledAuditArn: Option[ScheduledAuditArn] = scala
      .Option(impl.scheduledAuditArn())
      .map(value => zio.aws.iot.model.primitives.ScheduledAuditArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.CreateScheduledAuditResponse
  ): zio.aws.iot.model.CreateScheduledAuditResponse.ReadOnly = new Wrapper(impl)
}
